@@ -82,16 +82,8 @@ class Series(Data):
         """
         Reshape all dimensions but the last into a single dimension
         """
-        size = prod([s for i, s in enumerate(self.shape) if i in self.baseaxes])
-        newvalues = self.values.reshape(size, self.shape[-1])
-
-        if self.labels is not None:
-            fullshape = prod(self.labels.shape)
-            newlabels = self.labels.reshape(size, fullshape/size).squeeze()
-        else:
-            newlabels = None
-
-        return self._constructor(newvalues, labels=newlabels).__finalize__(self, noprop=('labels',))
+        size = prod(self.shape[:-1])
+        return self.reshape(size, self.shape[-1])
 
     def count(self):
         """
@@ -140,7 +132,7 @@ class Series(Data):
         if engine is None:
             raise ValueError('Must provide SparkContext')
 
-        return fromarray(self.toarray(), index=self.index, labels=self.lables, engine=engine)
+        return fromarray(self.toarray(), index=self.index, labels=self.labels, engine=engine)
 
     def sample(self, n=100, seed=None):
         """
@@ -256,6 +248,30 @@ class Series(Data):
         """
         return self._constructor(self.values.min(axis=self.baseaxes, keepdims=True))
 
+    def reshape(self, *shape):
+        """
+        Reshape the Series object
+
+        Cannot change the last dimension.
+
+        Parameters
+        ----------
+        shape: one or more ints
+            New shape
+        """
+        if prod(self.shape) != prod(shape):
+            raise ValueError("Reshaping must leave the number of elements unchanged")
+
+        if self.shape[-1] != shape[-1]:
+            raise ValueError("Reshaping cannot change the size of the constituent series (last dimension)")
+
+        if self.labels is not None:
+            newlabels = self.labels.reshape(*shape[:-1])
+        else:
+            newlabels = None
+
+        return self._constructor(self.values.reshape(shape), labels=newlabels).__finalize__(self, noprop=('labels',))
+
     def between(self, left, right):
         """
         Select subset of values within the given index range.
@@ -881,18 +897,15 @@ class Series(Data):
 
     def convolve(self, signal, mode='full'):
         """
-        Conolve series data against another signal.
+        Convolve series data against another signal.
 
         Parameters
         ----------
         signal : array
             Signal to convolve with (must be 1D)
 
-        var : str
-            Variable name if loading from a MAT file
-
         mode : str, optional, default='full'
-            Mode of convolution, options are 'full', 'same', and 'same'
+            Mode of convolution, options are 'full', 'same', and 'valid'
         """
 
         from numpy import convolve
@@ -958,7 +971,7 @@ class Series(Data):
             if n == 0:
                 b = zeros((s.shape[0],))
             else:
-                y /= norm(y)
+                y /= n
                 b = dot(s, y)
             return b
 
